===========================
Numpy Enhancement Proposals
===========================

Numpy Enhancement Proposals (NEPs) describe proposed changes to Numpy.
NEPs are modeled on Python Enhancement Proposals (PEPs), and are typically
written up when large changes to Numpy are proposed.

This page provides an overview of all NEPs, making only a distinction between
the ones that have been implemented and those that have not been implemented.

Implemented NEPs
----------------

.. toctree::
   :maxdepth: 1

   ufunc-overrides
   generalized-ufuncs
   new-iterator-ufunc
   npy-format

Other NEPs
----------

.. toctree::
   :maxdepth: 1

   missing-data
   math_config_clean
   groupby_additions
   warnfix
   newbugtracker
   deferred-ufunc-evaluation
   structured_array_extensions
   datetime-proposal
   datetime-proposal3
